pub enum OcrError {
Initialize(TessInitError),
AlreadyInitialized,
SetVariable(TessSetVariableError),
WritePnmImage(ImageError),
SetImage(PixError),
GetText(Utf8Error),
}Expand description
Error of the Ocr process with Tesseract.
Variants
Initialize(TessInitError)
Indicate than Tesseract could not be initialized.
AlreadyInitialized
Indicate than TESSERACT was already initialized on this thread
SetVariable(TessSetVariableError)
Indicate an error during Tesseract variable set.
WritePnmImage(ImageError)
Indicate than the pnm image couldn’t be wrote in memory.
SetImage(PixError)
Indicate a failure during set Pnm image to Tesseract.
GetText(Utf8Error)
Indicate than Tesseract failed to provide a text from the image.