pub struct Opt {
pub threshold: f32,
pub dpi: i32,
pub border: u32,
pub output: Option<PathBuf>,
pub tessdata_dir: Option<String>,
pub lang: String,
pub config: Vec<(Variable, String)>,
pub input: PathBuf,
pub dump: bool,
pub dump_raw: bool,
}Expand description
Handle application parameter from cli with Clap.
Fields
threshold: f32Threshold for subtitle image binarization.
Must be between 0.0 and 1.0. Only pixels with luminance above the threshold will be considered text pixels for OCR.
dpi: i32DPI of subtitle images.
This setting doesn’t strictly make sense for DVD subtitles, but it can influence Tesseract’s output.
border: u32Border in pixels to surround the each subtitle image for OCR.
This can have subtle effects on the quality of the OCR.
output: Option<PathBuf>Output subtitle file; stdout if not present.
tessdata_dir: Option<String>Path to Tesseract’s tessdata directory.
lang: StringThe Tesseract language(s) to use for OCR.
config: Vec<(Variable, String)>Set values for config variables.
This works like the tesseract command’s -c argument. One
particularly useful option is tessedit_char_blacklist=|\/_~` or
similar, to prevent the OCR from misidentifying characters as symbols
rarely used in subtitles.
input: PathBufSet the path of the file to process.
dump: boolDump processed subtitle images into the working directory as PNG files.
dump_raw: boolDump raw subtitle images into the working directory as PNG files.